@@ -5,6 +5,7 @@ import json
 import locale
 import utils
 from datetime import datetime
+from error import ParameterError
 
 def strptime(string, fmt = '%a %b %d %H:%M:%S +0000 %Y'):
 	locale.setlocale(locale.LC_TIME, 'C')
@@ -89,6 +90,15 @@ class MixedModelCollection(Model):
 			if hasattr(item, 'connect_api'):
 				item.connect_api(api)
 
+	def __len__(self):
+		return len(self.get(self.model_key, []))
+
+	def __getitem__(self, descriptor):
+		if type(descriptor) in [str, unicode]:
+			return Model.__getitem__(self, descriptor)
+		else:
+			return self.get(self.model_key, []).__getitem__(descriptor)
+
 class CursoredModelCollection(MixedModelCollection):
 	pass
 
@@ -214,7 +224,7 @@ class Message(Model):
 		for key, value in self.iteritems():
 			if key == 'created_at':
 				value = strptime(value)
-			elif key == 'sender' or key == 'receiver':
+			elif key == 'sender' or key == 'recipient':
 				value = User.from_json(value)
 			self[key] = value
 		return self
